clear all
clc

%RiSE_Compliance

%definitions
ground_plane=[0 0 1];

%robot varibles
robot=struct('cg',{[0,0,0.085]},...  %Center of the robot body in the world frame
    'orient',{[0,0,0]},... %Pitch, roll, and yaw angles in degrees
    'leg_posn',{[-0.075 0.137 0
                 -0.075 0 0 
                 -0.075 -0.137 0
                 0.075 0.137 0
                 0.075 0 0
                 0.075 -0.137 0]},... %body coordinates to each hip
    'leg_axes',{[0 1 0
                 0 1 0
                 0 1 0
                 0 -1 0
                 0 -1 0
                 0 -1 0]},... %hip rotation axis
    'leg_angles',{[30 -30
                   30 -30
                   30 -30
                   30 30
                   30 30
                   30 30]},... %initial leg angles, phi and psi for each, in degrees
    'width',{0.150},'length',{0.275},'height',{0.0625},...  %size of the robot body in meters
    'upper_leg_length',{0.040},'lower_leg_length',{0.120},'leg_width',{0.010},... %sizes for the legs
    'leg_depth',{0.010}, 'lower_rot_point',{0.05},... %lower_rot_point is the distance from the end of the leg of the center of compliance due to the leg springs
    'ankle_offsets',{[0 -0.010 0.008    %Compliance offset from foot/ground contact to the ankle in modified foot/ground coords
                      0 -0.010 0.008
                      0 -0.010 0.008
                      0 -0.010 0.008
                      0 -0.010 0.008
                      0 -0.010 0.008]});

[wgR,wgT] = getTransforms(ground_plane);
figure(1);
clf;
drawGroundPlane(robot,wgT);
[robot,wTr,T_b0,T_w1,T_w2]=robotVertices(robot);
drawRobot(robot,wTr,T_w1,T_w2);
[g_foot_out,w_foot_out,gwT,foot_pos,T_g1_s,T_g2_s] = footWorkspace(robot,wgR,wgT,wTr,T_b0);
drawFootWorkspace(w_foot_out);
robot.leg_angles=foot_placement_gui('robot',robot,'g_foot',g_foot_out,'wTr',wTr,'T_b0',T_b0,'gwT',gwT);
figure(2);
clf;
drawGroundPlane(robot,wgT);
[robot,wTr,T_b0,T_w1,T_w2]=robotVertices(robot);
drawRobot(robot,wTr,T_w1,T_w2);

H=[1 0 0 0 0 0    %Contact Constraint Matrix
   0 1 0 0 0 0
   0 0 1 0 0 0];

[jacobs,jacobs_sym,loop_eqn,jacob_eqn] = findJacobians(robot,foot_pos,T_g1_s,T_g2_s,H);

del_theta = null(jacob_eqn,'r')  %Null space of loop equations yields possible motions

del_xcg = -H*jacobs(:,:,1)*del_theta(1:2,:)

cond(jacob_eqn) %High condition indicates singular matrix (i.e., existence of null space)

Cjoint = [1/20 0
          0  1/20];

Cfoot = eye(6);

Cfoot = diag([0.0001 0.0001 0.002 10*pi/180 10*pi/180 90*pi/180]);
      
% Cfoot = [x x x x x x
%          x x x x x x
%          x x x x x x
%          x x x x x x
%          x x x x x x 
%          x x x x x x ];
         
% [bKeff,bKt] = findCompliance2(robot,foot_pos,T_g2_s,H,gwT,wTr,Cjoint,Cfoot,jacobs);
%[V,D]=eig(bKt)
