%function [gC,gCeff] = findComplianceOnlyWithLegSprings(robot,foot_pos,T_g2_s,H,gwT,wTr,Cjoint,Cankle,jacobs,feet,options,Cleg)
%Calculates effective stiffness at the robot CG, calculating effective
% compliance and stiffness at each foot that's in contact with the ground
% along the way - INCLUDES CHANGE WHICH ASSUMES THAT FOOT(ANKLE) COMPLIANCE
% MATRIX IS GIVEN IN A SYSTEM WHOSE Z AXIS IS PARALLEL TO THE GROUND SYSTEM
% Z AXIS - via "options" parameter, utilize different compliances:
%  1=joint only, 2=joint/legsprings only, 3=ankle only, 4=ankle/joint only, 5=joint/ankle/legsprings
% Stiffness is calculated for options 2 and 3 (not for joint only, which is
% usually singular)
% ADDS compliance due to leg springs

test=0; %Test harness
if test==1
    clear
    clc
    options=5;
    feet=[1 2 3];
    foot_pos=[2 0 0 1;0 3 0 1;-2 0 0 1]';
    robot.leg_posn=zeros(size(foot_pos,2),2);
    robot.leg_angles=zeros(size(foot_pos,2),2);
    robot.leg_axes=[0 1 0;0 1 0;0 1 0];
    robot.cg=[0 0 1];
    robot.lower_leg_length=0.120;
    robot.lower_rot_point=0.05;
    robot.ankle_offsets=[0 -0.010 0.008    %Compliance offset from foot/ground contact to the ankle in modified foot/ground coords
                         0 -0.010 0.008
                         0 -0.010 0.008
                         0 -0.010 0.008
                         0 -0.010 0.008
                         0 -0.010 0.008];
    for i=1:size(foot_pos,2)
        T_g2_s(:,:,i)=[[0 0 1;0 1 0;-1 0 0] foot_pos(1:3,i)+[0; 0; robot.lower_leg_length];0 0 0 1];
        jacobs = zeros(6,2,size(foot_pos,2));
    end
    gwT=eye(4);
    wTr=[eye(3) robot.cg';0 0 0 1];
    H=[eye(3) zeros(3)];
    Cankle = diag([0.002 0.002 0.005 50*pi/180 50*pi/180 60*pi/180]);
    Cjoint = diag([1/20 1/20]);
    Cleg = diag([0.00125 0 0 0 20*pi/180 0]); 
end


syms phi_s psi_s

grT = gwT*wTr;
grR = grT(1:3,1:3);

bKt = zeros(6);
for i=1:length(feet)
   % get velocity transforms from foot to body and tranform the ankle and leg compliance
    g_foot_pos(:,feet(i))=subs(foot_pos(:,feet(i)),{phi_s psi_s},{robot.leg_angles(feet(i),1)*pi/180,robot.leg_angles(feet(i),2)*pi/180});
    T_g2(:,:,feet(i)) = subs(T_g2_s(:,:,feet(i)),{phi_s psi_s},{robot.leg_angles(feet(i),1)*pi/180,robot.leg_angles(feet(i),2)*pi/180});
    gPgr = gwT*[robot.cg';1] - g_foot_pos(:,feet(i)); %vector, in ground coords, from foot to robot cg (homogeneous)
    gPgr = gPgr(1:3); %vector, in ground coords, from foot contact point to robot cg 
    gPgrX = [0 -gPgr(3) gPgr(2); gPgr(3) 0 -gPgr(1); -gPgr(2) gPgr(1) 0];
    gr_Tv(:,:,feet(i)) = [ grR gPgrX*grR; zeros(3) grR];
    gfR = T_g2(1:3,1:3,feet(i));
   % Leg spring compliance translation
    gPgl = T_g2(:,:,feet(i)) * [robot.lower_leg_length - robot.lower_rot_point;0;0;1] - [g_foot_pos(1:3,feet(i));0]; % This is (homogeneous) vector in ground coords from contact point to leg rotation point 
    gPglX = [0 -gPgl(3) gPgl(2); gPgl(3) 0 -gPgl(1); -gPgl(2) gPgl(1) 0];
    gl_Tv(:,:,feet(i)) = [ gfR gPglX*gfR; zeros(3) gfR]; %velocity transform from leg rotation point to ground contact point
    gCleg = gl_Tv(:,:,feet(i)) * Cleg * gl_Tv(:,:,feet(i))';
    gf_Tv(:,:,feet(i)) = [gfR zeros(3);zeros(3) gfR];
  %modification for ankle 'cause RiSE foot is pretty much already in wall coordinates - goal is to get modified foot x-axis in the ground x-y plane
  % Still not wholly confident that this is right.
    coser=dot(gfR(:,3),[0;0;1]);
    siner=norm(cross(gfR(:,3),[0;0;1]));
    Rprime=[coser 0 -siner;0 1 0;siner 0 coser];
    gfRmod(:,:,feet(i))=gfR*Rprime;
    % check to see if y is in general direction of ground y-axis.  If not,
    % spin 180 around z-axis
    if dot(gfRmod(:,2,feet(i)),[0;1;0])<0
        Rprime2=[-1 0 0;0 -1 0;0 0 1];
        gfRmod(:,:,feet(i))=Rprime2*gfRmod(:,:,feet(i));
    end
    %debugging
    %sprintf('Foot %d, gfR=%s, gfRmod=%s',feet(i),mat2str(gfR,4),mat2str(gfRmod(:,:,feet(i)),4))
  %Transforms from ankle to ground contact  
    gPgf(:,i) = gfRmod(:,:,feet(i))*(robot.ankle_offsets(feet(i),:)');  %vector from foot contact to ankle center point (ankle offset) in ground coords
    gPgfX = [0 -gPgf(3,i) gPgf(2,i); gPgf(3,i) 0 -gPgf(1,i); -gPgf(2,i) gPgf(1,i) 0]; %cross product matrix
    gf_Tv(:,:,feet(i)) = [gfRmod(:,:,feet(i)) gPgfX*gfRmod(:,:,feet(i));zeros(3) gfRmod(:,:,feet(i))]; %velocity transform from ankle to ground @ contact point
  %end of modification
    gCankle = gf_Tv(:,:,feet(i)) * Cankle * gf_Tv(:,:,feet(i))';
  %Theory Testing
    gf_Tf(:,:,feet(i)) = [ gfRmod(:,:,feet(i)) zeros(3); gPgfX*gfRmod(:,:,feet(i)) gfRmod(:,:,feet(i))]; %force transform from ankle to ground in ground coords
    fg_Tv(:,:,feet(i)) = inv(gf_Tv(:,:,feet(i))); %gf_Tf = fg_Tv'
  %End Theory Testing
  % Tranform joint compliance to the contact coordinates
    gCjoint = jacobs(:,:,feet(i)) * Cjoint * transpose(jacobs(:,:,feet(i)));

    
  % Add serial compliances based on options, 1=joint only, 2=joint/legsprings only, 3=ankle only, 4=ankle/leg only, 5=joint/ankle/legsprings
  switch options
    case 1
        gC(:,:,feet(i))=gCjoint;
    case 2
        gC(:,:,feet(i))=gCjoint + gCleg;
    case 3
        gC(:,:,feet(i))=gCankle;
    case 4
        gC(:,:,feet(i))=gCankle+gCleg;
    otherwise
        gC(:,:,feet(i))=gCankle + gCjoint + gCleg;
    end
   % Apply contact constraints
    gCeff(:,:,feet(i)) = H * gC(:,:,feet(i)) * H';
  % Invert to get stiffness, re-apply contact constraints to flesh out 6x6 matrix
    if options > 2
        gK = inv(gCeff(:,:,feet(i)));
        gKeff = H' * gK * H;
        % Transform to CG
        bKeff(:,:,feet(i)) = gr_Tv(:,:,feet(i))' * gKeff * gr_Tv(:,:,feet(i));
        bKt = bKt + bKeff(:,:,feet(i));
    end
end

