% Plot compliance ellipsoids at feet and CG

% options: 1=joint only, 2=joint/legsprings only, 3=ankle only, 4=ankle/joint only, 5=joint/ankle/legsprings

test=1;  %Set to 1 to implement test harness

foot = 1;
Cjoint = diag([1/20 1/20]);
Cleg = diag([0.00125 0 0 0 20*pi/180 0]); %Compliance due to leg springs - at a point up the lower leg from the contact point.
feet=[1 3 5];

if test==1  % Test Harness
    clear
    clc
    %definitions
    ground_plane=[0 0 1];
    %robot varibles
    robot=struct('cg',{[0,0,0.09177]},...  %Center of the robot body in the world frame
        'orient',{[0,0,0]},... %Pitch, roll, and yaw angles in degrees
        'leg_posn',{[-0.075 0.137 0
            -0.075 -0.137 0
            0.075 0 0]},... %body coordinates to each hip
        'leg_axes',{[0 1 0
            0 1 0
            0 -1 0]},... %hip rotation axis
        'leg_angles',{[55 30
            55 30
            55 -30]},... %initial leg angles, phi and psi for each, in degrees
        'width',{0.150},'length',{0.275},'height',{0.0625},...  %size of the robot body in meters
        'upper_leg_length',{0.040},'lower_leg_length',{0.120},'leg_width',{0.010},... %sizes for the legs
        'leg_depth',{0.010}, 'lower_rot_point',{0.05},... %lower_rot_point is the distance from the end of the leg of the center of compliance due to the leg springs
        'ankle_offsets',{[0 -0.010 0.008    %Compliance offset from foot/ground contact to the ankle in modified foot/ground coords
            0 -0.010 0.008
            0 -0.010 0.008
            0 -0.010 0.008
            0 -0.010 0.008
            0 -0.010 0.008]});
    robot.cg = [0 0 (robot.upper_leg_length + robot.lower_leg_length*cos(robot.leg_angles(1,2)*pi/180))*cos(robot.leg_angles(1,1)*pi/180)];
    feet=[1 2 3];
    %robot.ankle_offsets=zeros(6,3); %don't utilize ankle offset yet)
    [robot,wTr,T_b0,T_w1,T_w2]=robotVertices(robot);
    gwT=eye(4);
    wgT=inv(gwT);
    for i=1:size(robot.leg_posn,1)
        foot_pos(:,i) =[robot.leg_posn(i,:)';1] + [-robot.leg_axes(i,2)*(robot.upper_leg_length+robot.lower_leg_length*cos(robot.leg_angles(i,2)*pi/180))*sin(robot.leg_angles(i,1)*pi/180); robot.leg_axes(i,2)*robot.lower_leg_length*sin(robot.leg_angles(i,2)*pi/180);0;0];
        T_g2_s(:,:,i)=gwT*T_w2(:,:,i);
        jacobs = zeros(6,2,size(foot_pos,2));
    end
    H=[eye(3) zeros(3)];
    Cankle = diag([0.002 0.002 0.005 50*pi/180 50*pi/180 60*pi/180]);
    Cjoint = diag([1/20 1/20]);
    Cleg = diag([0.00125 0 0 0 20*pi/180 0]); 
end


figure(3)
clf;
Cankle = diag([0.002 0.002 0.005 50*pi/180 50*pi/180 60*pi/180]); %Compliance at ankle
options=1;
findComplianceOnlyWithLegSprings;
[VsOrig,DsOrig]=robotWithEllipsesComplianceOnly(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,gCeff,g_foot_pos,gfRmod,gPgf);
title('Original Foot Compliance - Joint Compliance');
%print -djpeg100 orig_joint_comp.jpg
figure(4)
options=4;
findComplianceOnlyWithLegSprings;
[VsOrig,DsOrig]=robotWithEllipsesComplianceOnly(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,gCeff,g_foot_pos,gfRmod,gPgf);
title('Original Foot Compliance - Leg/Foot Structural Compliance');
%print -djpeg100 orig_struct_comp.jpg
figure(5)
options=5;
findComplianceOnlyWithLegSprings;
[VsOrig,DsOrig]=robotWithEllipsesComplianceOnly(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,gCeff,g_foot_pos,gfRmod,gPgf);
title('Original Foot Compliance - Total Compliance');
%print -djpeg100 orig_total_comp.jpg
figure(6)
[VsKorig,DsKorig]=robotWithEllipses(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,bKeff,bKt,H);
title('Original Foot Stiffness - Total Stiffness');
%print -djpeg100 orig_total_stiff.jpg

figure(7)
clf;
Cankle = diag([0.0001 0.0001 0.0001 2*pi/180 2*pi/180 60*pi/180]);
options=1;
findComplianceOnlyWithLegSprings;
[VsZip,DsZip]=robotWithEllipsesComplianceOnly(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,gCeff,g_foot_pos,gfRmod,gPgf);
title('Zip Tie Foot Compliance - Joint Compliance');
%print -djpeg100 zip_joint_comp.jpg
figure(8)
options=4;
findComplianceOnlyWithLegSprings;
[VsZip,DsZip]=robotWithEllipsesComplianceOnly(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,gCeff,g_foot_pos,gfRmod,gPgf);
title('Zip Tie Foot Compliance - Leg/Foot Structural Compliance');
%print -djpeg100 zip_struct_comp.jpg
figure(9)
options=5;
findComplianceOnlyWithLegSprings;
[VsZip,DsZip]=robotWithEllipsesComplianceOnly(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,gCeff,g_foot_pos,gfRmod,gPgf);
title('Zip Tie Foot Compliance - Total Compliance');
%print -djpeg100 zip_total_comp.jpg
figure(10)
[VsKzip,DsKzip]=robotWithEllipses(robot,wgT,wTr,T_w1,T_w2,foot_pos,feet,bKeff,bKt,H);
title('Zip Tie Foot Stiffness - Total Stiffness');
%print -djpeg100 zip_total_stiff.jpg


