function [robot,wTr,T_b0,T_w1,T_w2] = robotVertices(robot)
%Robot Body in robot frame (homogeneous)
robot.body_vertices = [-robot.width/2 -robot.length/2 -robot.height/2 1    %1
                       -robot.width/2 -robot.length/2  robot.height/2 1    %2
                       -robot.width/2  robot.length/2 -robot.height/2 1    %3
                       -robot.width/2  robot.length/2  robot.height/2 1    %4
                        robot.width/2  robot.length/2 -robot.height/2 1    %5
                        robot.width/2  robot.length/2  robot.height/2 1    %6
                        robot.width/2 -robot.length/2 -robot.height/2 1    %7
                        robot.width/2 -robot.length/2  robot.height/2 1 ]; %8
robot.body_faces = [1 2 4 3
                    3 4 6 5
                    5 6 8 7
                    7 8 2 1
                    2 4 6 8
                    1 3 5 7];

%Convert robot_body into world frame
gamma = robot.orient(1)*pi/180; %pitch
beta = robot.orient(2)*pi/180;  %roll
alpha = robot.orient(3)*pi/180; %yaw
Rx = [1 0 0;0 cos(gamma) -sin(gamma);0 sin(gamma) cos(gamma)];
Ry = [cos(beta) 0 sin(beta);0 1 0; -sin(beta) 0 cos(beta)];
Rz = [cos(alpha) -sin(alpha) 0;sin(alpha) cos(alpha) 0; 0 0 1];
wTr = [Rz*Ry*Rx;[0 0 0]];
wTr = [wTr [robot.cg';1]];

%leg vertices in respective leg frame (homogeneous)
robot.upper_leg_vertices = [0                      -robot.leg_width/2 -robot.leg_depth/2 1   %1
                            0                      -robot.leg_width/2  robot.leg_depth/2 1   %2
                            robot.upper_leg_length -robot.leg_width/2 -robot.leg_depth/2 1   %3
                            robot.upper_leg_length -robot.leg_width/2  robot.leg_depth/2 1   %4
                            robot.upper_leg_length  robot.leg_width/2 -robot.leg_depth/2 1   %5
                            robot.upper_leg_length  robot.leg_width/2  robot.leg_depth/2 1   %6
                            0                       robot.leg_width/2 -robot.leg_depth/2 1   %7
                            0                       robot.leg_width/2  robot.leg_depth/2 1 ];%8

robot.lower_leg_vertices = [0                       -robot.leg_width/2 -robot.leg_depth/2 1   %1
                            0                       -robot.leg_width/2  robot.leg_depth/2 1   %2
                            robot.lower_leg_length  -robot.leg_width/2 -robot.leg_depth/2 1   %3
                            robot.lower_leg_length  -robot.leg_width/2  robot.leg_depth/2 1   %4
                            robot.lower_leg_length   robot.leg_width/2 -robot.leg_depth/2 1   %5
                            robot.lower_leg_length   robot.leg_width/2  robot.leg_depth/2 1   %6
                            0                        robot.leg_width/2 -robot.leg_depth/2 1   %7
                            0                        robot.leg_width/2  robot.leg_depth/2 1 ];%8
                        
robot.leg_faces = robot.body_faces;

for i=1:length(robot.leg_angles)
    phi=robot.leg_angles(i,1)*pi/180;  %wing angle
    psi=robot.leg_angles(i,2)*pi/180;    %crank angle
    T_12(:,:,i) = [cos(psi) -sin(psi)  0  robot.upper_leg_length
                   0        0         -1  0
                   sin(psi) cos(psi)   0  0
                   0        0          0  1];  %Lower leg coordinate system
    T_01(:,:,i) = [cos(phi) -sin(phi)   0     0
                   sin(phi)  cos(phi)   0     0
                   0           0        1     0
                   0           0        0     1];  %Upper leg coordinate system
    %get hip axes w/ z along hip and x pointing down
    x=[0;0;-1]; 
    z=robot.leg_axes(i,:)';
    y=cross(z,x);
    T_b0(:,:,i) =  [ [x;0] [y;0] [z;0] [robot.leg_posn(i,:)';1] ];  % Center of robot to hip position
    T_w1(:,:,i) = wTr * T_b0(:,:,i) * T_01(:,:,i);
    T_w2(:,:,i) = T_w1(:,:,i) * T_12(:,:,i);
end
